#!/usr/bin/env python
from dapodik.main import main

if __name__ == "__main__":
    main()
